import argparse


class MyParser:

    def __init__(self):
        parser = argparse.ArgumentParser()
        parser.add_argument('-q', '--query',
                            help='query you want to check',
                            type=str, default='Global warming')
        parser.add_argument('-u', '--badsites',
                            help='list of unreliable sites',
                            type=str, default='badsites.csv')
        parser.add_argument('-b', '--baits',
                            help='list of baits expressions',
                            type=str, default='baits.csv')
        parser.add_argument('-o', '--opinions',
                            help='list of opinion expressions',
                            type=str, default='opinionwords.csv')

        self.args = parser.parse_args()



from post_truth_checker.page import Page


def get_base_link_test_http():
    url = 'http//www.wikipedia.com'
    assert Page.get_base_link(url) == 'www.wikipedia.com'


def get_base_link_test_www():
    url = 'www.wikipedia.com'
    assert Page.get_base_link(url) == 'www.wikipedia.com'


def get_base_link_test():
    url = 'wikipedia.com'
    assert Page.get_base_link(url) == 'www.wikipedia.com'


def skip_site_test():
    assert Page.skip_site('google.com', 'facebook.com')



import sys
import os
from post_truth_checker.my_parser import MyParser
from post_truth_checker.sources_loader import SourcesLoader
from post_truth_checker.page import Page
from urllib import error
try:
    from google import search
except (ImportError, AttributeError):
    sys.exit("You need google library. Run 'pip install google'.")

max_url_length = 60


def searching(query, sources):
    i = 0
    print('searching...')
    for url in search(query, stop=10, pause=5.0):
        if len(url) < max_url_length:
            i += 1
            print('\n', i, ':')
            try:
                pg = Page(url)
                pg.get_links(sources.fake_sites)
                ci = pg.get_title_clickbait_index(sources.clickbait_words)
                if ci > 3:
                    print('Warning! ', end="")

                print('Clickbait title index of this article is: ', ci)
                oi = pg.get_opinion_index(sources.opinion_words)
                if oi > 3:
                    print('Warning! ', end="")
                print('Opinion index of this article is: ', oi)

            except (error.URLError, error.HTTPError):
                print('Skipped site ', url, "because of url/http error")


def run(query):
    info()
    if not query:
        print("No query was entered. "
              "Type some information you want to check out!")
        return
    badsites = os.path.join(os.path.dirname(__file__), 'badsites.csv')
    baits = os.path.join(os.path.dirname(__file__), 'badsites.csv')
    opinions = os.path.join(os.path.dirname(__file__), 'opinionwords.csv')
    sources = SourcesLoader(badsites, baits, opinions)
    searching(query, sources)


def info():
    print("""Program will check reliability of websites searched from input
                query. Returns indexes of specified reliability from zero
                (nothing suspicious was found), upwards(the higher the worse).
                """)


def main():
    p = MyParser()
    query = p.args.query
    info()
    if query:
        query = query.replace('-', ' ')
    else:
        print("No query was entered. "
              "Type some information you want to check out!")
        return

    sources = SourcesLoader(p.args.badsites, p.args.baits, p.args.opinions)
    searching(query, sources)


if __name__ == "__main__":
    main()



import urllib
from bs4 import BeautifulSoup
from urllib.request import Request
import urllib.request


class Page:
    def __init__(self, url):
        self.url = url
        req = Request(url, headers={'User-Agent': 'Mozilla/5.0'})
        self.page = urllib.request.urlopen(req)
        self.soup = BeautifulSoup(self.page, "html5lib")

    def get_title_clickbait_index(self, clickbait_words):
        try:
            title = self.soup.title.string
        except AttributeError:
            return 0
        title = title.split(' ')
        counter = 0
        for t in title:
            if t.lower() in clickbait_words or t.isdigit():
                counter += 1
            if '?' in t or '!' in t:
                counter += 2
        return counter

    def get_opinion_index(self, opinion_words):
        text = self.soup.find_all('p')
        counter = 0
        for line in text:
            words = str(line).split(' ')
            for word in words:
                if word.lower() in opinion_words:
                    counter += 1

        return counter

    def get_links(self, fake_sites):
        s = set()
        print(self.url)

        for tag in self.soup.findAll('a', href=True):
            tag['href'] = urllib.parse.urljoin(self.url, tag['href'])
            if not self.skip_site(self.url, tag['href']):
                s.add(self.get_base_link(tag['href']))
        for site in s:
            if site in fake_sites or (self.get_base_link(self.url)
                                      in fake_sites):
                print('contains link to unreliable site ' + site)

    @staticmethod
    def skip_site(url1, url2):
        s1 = Page.get_base_link(url1)
        s2 = Page.get_base_link(url2)
        return (s1 == s2 or
                'twitter' in url2 or 'facebook' in url2)

    @staticmethod
    def get_base_link(url):
        s1 = url.split('/')

        if 'http:' in s1 or 'https:' in s1:
            return s1[2]

        elif 'www' in s1[0]:
            return s1[0]
        else:
            s1[0] = 'www.' + s1[0]
            return s1[0]



class SourcesLoader:
    def __init__(self, unreliable_sites, clickbait, opinion):
        self.fake_sites = {line.rstrip()
                           for line in open(unreliable_sites, "r")}
        self.clickbait_words = {line.rstrip().lower()
                                for line in open(clickbait, "r")}
        self.opinion_words = {line.rstrip().lower()
                              for line in open(opinion, "r")}



from setuptools import setup


def reqs():
    with open('requirements.txt') as f:
        return f.read().splitlines()


def readme():
    with open('README.rst') as f:
        return f.read()


setup(name='post_truth_checker',
      version='0.2',
      description='Checks reliability of sites',
      long_description=readme(),
      url='https://github.com/AGHPythonCourse2017/zad3-detori',
      author='Wojciech Kubaty',
      include_package_data=True,
      install_requires=reqs(),
      packages=['post_truth_checker'],
      zip_safe=False)
